@@ -16,13 +16,13 @@ process_data <- function(data, filter, by, free.scales, is.colors, split.by=TRUE
 			sel <- by==l
 			sel[is.na(sel)] <- FALSE
 			dat2 <- if (cls[1]=="fac") {
-				ch <- ifelse(sel, as.character(dat), NA) 
+				ch <- as.character(dat)
+				ch[!sel] <- NA
 				lvls <- if (free.scales) intersect(xlvls, ch) else xlvls
 				factor(ch, levels=lvls)
 			} else {
-				if (split.by) {
-					ifelse(sel, dat, NA)	
-				} else dat
+				if (split.by) dat[!sel] <- NA
+				dat
 			}
 			
 			attr(dat2, "sel") <- sel
@@ -33,8 +33,8 @@ process_data <- function(data, filter, by, free.scales, is.colors, split.by=TRUE
 		
 		names(X) <- levels(by)
 		if (cls[1]=="col" || !vary) {
-			M <- matrix(unlist(X), ncol=nby)
-			sel  <- matrix(unlist(Xsel), ncol=nby)
+			M <- do.call(cbind, X) #matrix(unlist(X), ncol=nby)
+			sel  <- do.call(cbind, Xsel) #matrix(unlist(Xsel), ncol=nby)
 			
 			attr(M, "sel") <- sel
 			attr(M, "anyNA") <- apply(is.na(M) & sel, MARGIN = 2, any)
@@ -42,11 +42,11 @@ process_data <- function(data, filter, by, free.scales, is.colors, split.by=TRUE
 
 			return(M)
 		} else if (!free.scales) {
-			Y <- unlist(X)
-			attr(Y, "sel") <- unlist(Xsel)
+			Y <- unlist(X, use.names = FALSE)
+			attr(Y, "sel") <- unlist(Xsel, use.names = FALSE)
 		} else {
 			Y <- X
-			attr(Y, "sel") <- matrix(unlist(Xsel), ncol=nby)
+			attr(Y, "sel") <- do.call(cbind, Xsel) #matrix(unlist(Xsel), ncol=nby)
 		}
 		
 		attr(Y, "anyNA") <- vapply(X, function(i) any(is.na(i) & attr(i, "sel")), logical(1))
@@ -75,15 +75,15 @@ process_data <- function(data, filter, by, free.scales, is.colors, split.by=TRUE
 					})
 				}
 				
-				datavec <- unlist(data)
+				datavec <- unlist(data, use.names = FALSE)
 				if (all(cls == "uni")) attr(datavec, "units") <- as.character(uni)
 			} else {
 				xlvls_list <- mapply(function(d, cl){
 					if (cl=="fac") levels(d) else na.omit(unique(d))
 				}, data, cls, SIMPLIFY=FALSE)
 				
-				xlvls <- unique(unlist(xlvls_list))
-				datavec <- factor(unlist(lapply(data, as.character)), levels=xlvls)
+				xlvls <- unique(unlist(xlvls_list, use.names = FALSE))
+				datavec <- factor(unlist(lapply(data, as.character), use.names = FALSE), levels=xlvls)
 			}
 
 			attr(datavec, "sel") <- sel
