@@ -35,19 +35,19 @@ process_layers <- function(g, z, gt, gf, interactive) {
 	scale <- gt$scale
 	
 	if (!is.null(data) && attr(data, "treat_as_by")) {
-		data$GROUP_BY <- factor("_NA_")
+		data$GROUP_BY <- factor("___NA___")
 		by <- NA
 		ncol <- NA
 		nrow <- NA
 		panel.names <- setdiff(names(data), c("tmapfilter", "GROUP_BY"))
 		treat_by_count <- length(panel.names)
 	} else if (g$tm_shape$by[1]=="") {
-		data$GROUP_BY <- factor("_NA_")
+		data$GROUP_BY <- factor("___NA___")
 		by <- NA
 		ncol <- NA
 		nrow <- NA
 		panel.names <- NA
-		treat_by_count <- 1
+		treat_by_count <- 1L
 	} else {
 		if (!all(g$tm_shape$by %in% names(data))) stop("Variable(s) \"", paste(setdiff(g$tm_shape$by, names(data)), collapse=", "), "\" not found in ", g$tm_shape$shp_name, call.=FALSE)
 		
@@ -80,14 +80,14 @@ process_layers <- function(g, z, gt, gf, interactive) {
 			nrow <- nlevels(d2[[1]])
 			panel.names <- list(levels(d2[[1]]), levels(d2[[2]]))
 		}
-		treat_by_count <- 1
+		treat_by_count <- 1L
 	}
 	
 	a <- g$tm_shape$along
 	if (a=="" || interactive) {
 		if (a!="") warning("along not supported in view mode", call. = FALSE)
 		alev <- NA
-		data$ALONG <- factor("_NA_")
+		data$ALONG <- factor("___NA___")
 		along.names <- NA
 	} else {
 		if (!(a %in% names(data))) stop("Variable \"", a, "\" not found in ", g$tm_shape$shp_name, call.=FALSE)
@@ -148,6 +148,7 @@ process_layers <- function(g, z, gt, gf, interactive) {
 	# fill info
 	if (is.null(g$tm_fill)) {
 		fill.group <- if (is.null(g$tm_borders)) NA else g$tm_borders$group
+		fill.zindex <- if (is.null(g$tm_borders)) NA else g$tm_borders$zindex
 		gfill <- list(fill=NULL, xfill=NA, fill.legend.title=NA, fill.id=NA, fill.group = fill.group, fill.zindex = NA) 
 	} else {
 		g$tm_fill$gborders <- gborders
